#
# spec file for package leftwm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           leftwm
Version:        0.5.1
Release:        1.2
Summary:        A tiling window manager for adventurers
License:        Apache-2.0 AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR MIT OR MPL-2.0) AND BSD-2-Clause AND BSD-3-Clause AND (MIT OR Unlicense)
Group:          System/GUI/Other
URL:            https://github.com/leftwm/leftwm
Source0:        https://github.com/leftwm/leftwm/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Source2:        %{name}-rpmlintrc
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  libX11-devel
BuildRequires:  libXinerama-devel
BuildRequires:  libXrandr-devel
BuildRequires:  zstd
Recommends:     xorg-x11-server
Suggests:       polybar
Suggests:       lemonbar
Suggests:       rofi
Suggests:       dunst

%description
LeftWM is a tiling window manager written in Rust that aims to be stable and performant.

%prep
%autosetup -a1

%build
%{cargo_build}

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -D -d -m 0755 %{buildroot}%{_datadir}
install -D -d -m 0755 %{buildroot}%{_datadir}/xsessions
install -D -d -m 0755 %{buildroot}%{_mandir}
install -D -d -m 0755 %{buildroot}%{_mandir}/man1
install -m 0644 %{name}/doc/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
install -m 0644 %{name}.desktop %{buildroot}%{_datadir}/xsessions/%{name}.desktop

install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name} %{buildroot}%{_bindir}/%{name}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name}-worker %{buildroot}%{_bindir}/%{name}-worker
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name}-state %{buildroot}%{_bindir}/%{name}-state
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name}-command %{buildroot}%{_bindir}/%{name}-command
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name}-check %{buildroot}%{_bindir}/%{name}-check
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/lefthk-worker %{buildroot}%{_bindir}/lefthk-worker

%files
%license LICENSE.md
%doc README.md CONTRIBUTING.md CHANGELOG.md themes
%{_bindir}/leftwm
%{_bindir}/leftwm-worker
%{_bindir}/leftwm-state
%{_bindir}/leftwm-check
%{_bindir}/leftwm-command
%{_bindir}/lefthk-worker
%{_datadir}/xsessions/leftwm.desktop
%{_mandir}/man1/leftwm.1%{?ext_man}

%changelog
* Mon Mar 11 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.5.1:
  * The layouts and workspace.layouts in config.ron must be declared as
  Strings because they are no longer backed by an enum. (ie. use layouts:
  ["CenterMain"] instead of layouts: [CenterMain])
  * The max_window_width config was removed without direct replacement. The
  "always fill entire screen" behavior can now be addressed by creating a
  custom layout with an appropriate Reserve property.
  * LeftWM now depends on lefthk ^0.2.0, which has been refactored
  * Dialog windows correctly obey their spawned sized
  * Fixes to location of spawned windows
  * Fixes to full-screened windows
  * Maximized windows no longer hide the dock
  * Fixes to ordering of windows after exiting from full screen mode
  * Basic theme and documentation fixes
  * Improved performance for set_layout , event_loop, and Xscreens
  * Improved error messages for leftwm-state and leftwm-check
  * Cursors now snap to the bottom right of a window when resizing
  * The new ignore_empty and ignore_used options in FocusNext/Previous Tag
  * Command SwapWindowToTop introduced
* Sun Sep 10 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Use upstream tarball
- Update vendored dependencies
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual` in service file.
* Sun Jun 25 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0.4.2:
  * prepare 0.4.2 release (#1089)
  * Add Optional Behavior Settings for FocusNextTag and
    FocusPreviousTag (#1086)
  * feat(leftwm-check): Add a check for other binaries to
    leftwm-check so that packagers can ensure all current binaries
    are installed. (#1077)
  * update deps and fix builderror with `git_version` macro (#1075)
  * fix basic_lemonbar template.liquid (#1080)
  * fix - when window gets detroyed, find the last focused (#1055)
  * on entering fullscreen, save order. On exit, restore. (#1052)
  * docs(themes/basic_eww): correct writing and improve formatting
    (#1076)
  * Make configuration errors more visible (#1072)
  * Simplify async tests with `tokio::test` (#1069)
- Added _service file
* Fri Feb  3 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add suggested packages with leftwm
- Add filters for rpmlintrc
* Fri Jan 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for leftwm 0.4.0+git56
